@@ -108,8 +108,8 @@ class SecurityDataClient(object):
                 str format "yyyy-MM-DD HH:MM:SS" or a datetime instance. Defaults to None.
 
         Returns:
-            generator: An object that iterates over :class:`py42.response.Py42Response` objects
-            that each contain a page of events.
+            generator: An object that iterates over tuples whose first element is a :class:`py42.response.Py42Response` object
+            containing a page of events, and whose second element is a string cursor.
         """
         return self._get_security_detection_events(
             plan_storage_info,
@@ -158,8 +158,8 @@ class SecurityDataClient(object):
                 str format "yyyy-MM-DD HH:MM:SS" or a datetime instance. Defaults to None.
 
         Returns:
-            generator: An object that iterates over :class:`py42.response.Py42Response` objects
-            that each contain a page of events.
+            generator: An object that iterates over tuples whose first element is a :class:`py42.response.Py42Response` object
+            containing a page of events, and whose second element is a string cursor.
         """
         security_plan_storage_infos = self.get_security_plan_storage_info_list(user_uid)
         return self._get_security_detection_events(
@@ -173,7 +173,7 @@ class SecurityDataClient(object):
 
     def search_file_events(self, query):
         """Searches for file events, returns up to the first 10,000 events.
-        `REST Documentation <https://support.code42.com/Administrator/Cloud/Monitoring_and_managing/Forensic_File_Search_API>`__
+        `REST Documentation <https://developer.code42.com/api/#operation/searchEventsUsingPOST>`__
 
         Args:
             query (str or :class:`py42.sdk.queries.fileevents.file_event_query.FileEventQuery`):
@@ -187,8 +187,7 @@ class SecurityDataClient(object):
 
     def search_all_file_events(self, query, page_token=""):
         """Searches for all file events, returning a page of events with a token in the response to retrieve next page.
-
-        `REST Documentation <https://support.code42.com/Administrator/Cloud/Monitoring_and_managing/Forensic_File_Search_API>`__
+        `REST Documentation <https://developer.code42.com/api/#operation/searchEventsUsingPOST>`__
 
         Args:
             query (str or :class:`py42.sdk.queries.fileevents.file_event_query.FileEventQuery`):
