@@ -1,4 +1,4 @@
-from py42.sdk.queries.query_filter import filter_attributes
+from py42.util import get_attribute_keys_from_class
 
 
 class SortDirection(object):
@@ -9,4 +9,4 @@ class SortDirection(object):
 
     @staticmethod
     def choices():
-        return filter_attributes(SortDirection)
+        return get_attribute_keys_from_class(SortDirection)
