@@ -253,6 +253,14 @@ class QueryFilterTimestampField(object):
 
     _term = u"override_timestamp_field_name"
 
+    @staticmethod
+    def _parse_timestamp(value):
+        return parse_timestamp_to_milliseconds_precision(value)
+
+    @staticmethod
+    def _convert_datetime_to_timestamp(value):
+        return convert_datetime_to_timestamp_str(value)
+
     @classmethod
     def on_or_after(cls, value):
         """Returns a :class:`~py42.sdk.queries.query_filter.FilterGroup` that is useful
@@ -265,7 +273,7 @@ class QueryFilterTimestampField(object):
         Returns:
             :class:`~py42.sdk.queries.query_filter.FilterGroup`
         """
-        formatted_timestamp = parse_timestamp_to_milliseconds_precision(value)
+        formatted_timestamp = cls._parse_timestamp(value)
         return create_on_or_after_filter_group(cls._term, formatted_timestamp)
 
     @classmethod
@@ -280,7 +288,7 @@ class QueryFilterTimestampField(object):
         Returns:
             :class:`~py42.sdk.queries.query_filter.FilterGroup`
         """
-        formatted_timestamp = parse_timestamp_to_milliseconds_precision(value)
+        formatted_timestamp = cls._parse_timestamp(value)
         return create_on_or_before_filter_group(cls._term, formatted_timestamp)
 
     @classmethod
@@ -290,14 +298,16 @@ class QueryFilterTimestampField(object):
         the provided ``start_value`` and ``end_value``.
 
         Args:
-            start_value (str or int or float or datetime): The start value used to filter results.
-            end_value (str or int or float or datetime): The end value used to filter results.
+            start_value (str or int or float or datetime): The start value used to
+                filter results.
+            end_value (str or int or float or datetime): The end value used to
+                filter results.
 
         Returns:
             :class:`~py42.sdk.queries.query_filter.FilterGroup`
         """
-        formatted_start_time = parse_timestamp_to_milliseconds_precision(start_value)
-        formatted_end_time = parse_timestamp_to_milliseconds_precision(end_value)
+        formatted_start_time = cls._parse_timestamp(start_value)
+        formatted_end_time = cls._parse_timestamp(end_value)
         return create_in_range_filter_group(
             cls._term, formatted_start_time, formatted_end_time
         )
@@ -314,7 +324,7 @@ class QueryFilterTimestampField(object):
         Returns:
             :class:`~py42.sdk.queries.query_filter.FilterGroup`
         """
-        if isinstance(value, str):
+        if isinstance(value, string_type):
             value = convert_datetime_to_epoch(datetime.strptime(value, DATE_STR_FORMAT))
         elif isinstance(value, datetime):
             value = convert_datetime_to_epoch(value)
@@ -325,8 +335,8 @@ class QueryFilterTimestampField(object):
         end_time = datetime(
             date_from_value.year, date_from_value.month, date_from_value.day, 23, 59, 59
         )
-        formatted_start_time = convert_datetime_to_timestamp_str(start_time)
-        formatted_end_time = convert_datetime_to_timestamp_str(end_time)
+        formatted_start_time = cls._convert_datetime_to_timestamp(start_time)
+        formatted_end_time = cls._convert_datetime_to_timestamp(end_time)
         return create_in_range_filter_group(
             cls._term, formatted_start_time, formatted_end_time
         )
